<?php
/**
 * Overall Grade
 *
 * @since 3.0.0
 *
 * @package LearnDash_Gradebook
 * @subpackage LearnDash_Gradebook/includes
 */

defined( 'ABSPATH' ) || die();

/**
 * Class LD_GB_OverallGrade
 *
 * Contains the grade for a given user.
 *
 * @since 3.0.0
 *
 * @package LearnDash_Gradebook
 * @subpackage LearnDash_Gradebook/includes
 */
class LD_GB_OverallGrade {

    /**
	 * Whether or not this has been output.
	 *
	 * @since 3.0.0
	 *
	 * @var bool
	 */
	private $used = false;

	/**
	 * LD_GB_OverallGrade constructor.
	 *
	 * @since 3.0.0
	 */
	function __construct() {

	}

	/**
	 * Renders the output.
	 *
	 * @since 3.0.0
	 *
	 * @param array $atts
	 * @param string $content
	 *
	 * @return mixed
	 */
	public function render( $atts = array(), $is_block = false ) {

		// Remove empty data
		$atts = array_filter( $atts );

        $atts = shortcode_atts( array(
			'user'               => get_current_user_id(),
			'gradebook'          => false,
			'format'			 => ld_gb_get_option_field( 'grade_display_mode', 'letter' ),
			'logged_out_message' => __( 'Please log in to view your overall grade.', 'learndash-gradebook' ),
		), $atts, 'ld_overall_grade' );

		if ( ! is_user_logged_in() ) {
			return '<div class="ld-gb-report-card-overall">' . $atts['logged_out_message'] . '</div>';
		}
        
        if ( ! $atts['gradebook'] ) {
            return '<div class="ld-gb-report-card-overall">' . __( 'You must define a Gradebook ID.', 'learndash-gradebook' ) . '</div>';
        }

		// Get user
		if ( ! ( $user = get_user_by( 'id', $atts['user'] ) ) ) {
			return '<div class="ld-gb-report-card-overall">' . __( 'Cannot get user.', 'learndash-gradebook' ) . '</div>';
		}

		$gradebook_id = $atts['gradebook'];

		ob_start();

        if ( ! get_post( $gradebook_id ) ) {

            ld_gb_locate_template( 'overall-grade/overall-grade-error.php', array(
                'gradebook_id' => $gradebook_id,
				'is_block' => $is_block,
            ) );
            
        }
        else {

            $user_grade = new LD_GB_UserGrade( $user, $gradebook_id );

            // Allow the theme to load the template instead of the plugin
            ld_gb_locate_template( 'overall-grade/overall-grade.php', array(
                'user_grade' => $user_grade,
				'gradebook_id' => $gradebook_id,
				'format' => $atts['format'],
				'is_block' => $is_block,
            ) );

        }

		return ob_get_clean();
    }
    
}